# Qtile Ebenezer 🪨

This repository provides a collection of widgets and behaviors spanning Desktop to Qtile Tiling Window Manager.


# The name

This theme was named Ebenezer 🪨, which meaning "stone of helper.".

> The quote is from I Samuel 7. After defeating the Philistines, Samuel raises his Ebenezer, declaring that God defeated the enemies on this spot. As a result, "hither by thy help I come." So I hope this stone helps you in your environment and, more importantly, in your life. 🙏🏿


## Installation

```shell
pip install ebenezer
```

# The Ebenezer CLI

A CLI tool for backlight, wallpaper, volume control and other helpers.

## Usage

```shell
ebenezer backlight --help
ebenezer volume --help
ebenezer wallpaper --help
```


# Documentation

You may access library documentation generated with Sphinx [here](https://qtile-ebenezer.readthedocs.io/en/latest/).

Thank you for the Read The Docs open source support. ❤️